@announce
Feature: Fetch remotely stored bundle

  Scenario: No Gemfile
    Given there is no Gemfile.lock in the current directory
     When I run `bundle-depot fetch`
     Then the output should contain "Couldn't find Gemfile.lock"
     And the exit status should not be 0

  Scenario: Working directory defaults to ./bundle/depot
    Given there is the project "json" in the current directory
     When I run `bundle-depot fetch`
     Then the following directories should exist:
       | .bundle/depot/cache   |  
       | .bundle/depot/current |  

  Scenario: Local Cache can be overwritten by environment 
    Given there is the project "json" in the current directory
      And the following environment variables are set:
          | variable                  | value               |
          | BUNDLE_DEPOT_CACHE        | special/depot/cache |
     When I run `bundle-depot fetch`
    Then the following directories should exist:
          | special/depot/cache/bde95daa2ce7dede336b4367b9e3a0690027bd6f071e0fdcb1b3047cf988963c |  
     And the following symlinks should exist:
          | source                | target                                                                               |
          | .bundle/depot/current | special/depot/cache/bde95daa2ce7dede336b4367b9e3a0690027bd6f071e0fdcb1b3047cf988963c |


  Scenario: Does nothing if local cache contains the bundle
    Given there is the project "json" in the current directory
      And the local cache contains the bundle "json"
     When I run `bundle-depot fetch`
     Then the exit status should be 0 

  Scenario: .bundle/depot/current points to 
    Given there is the project "json" in the current directory
     When I run `bundle-depot fetch`
     Then the following symlinks should exist:
       | source                | target                                                                               |
       | .bundle/depot/current | .bundle/depot/cache/bde95daa2ce7dede336b4367b9e3a0690027bd6f071e0fdcb1b3047cf988963c |

  Scenario: Skip remote check if SCP is not setup
    Given there is the project "json" in the current directory
     When I run `bundle-depot fetch`
     Then the output should not contain "=> Bundle is not in remote cache"

  Scenario: Check remote cache when SCP is setup
    Given there is the project "json" in the current directory
      And the following environment variables are set:
          | variable                  | value               |
          | BUNDLE_DEPOT_SCP_USER     | upload              | 
          | BUNDLE_DEPOT_SCP_PASS     | upload              |
          | BUNDLE_DEPOT_SCP_HOST     | cache.example.com   |
      And the remote cache contains the packed bundle for "json" 
      And the local cache does not contain the bundle "json"
     When I run `bundle-depot fetch`
     Then the output should contain "=> Bundle found in remote cache. Downloading!"

  Scenario: Does nothing if the remote cache does not contain the bundle 
    Given there is the project "json" in the current directory
      And the following environment variables are set:
          | variable                  | value               |
          | BUNDLE_DEPOT_SCP_USER     | upload              | 
          | BUNDLE_DEPOT_SCP_PASS     | upload              |
          | BUNDLE_DEPOT_SCP_HOST     | cache.example.com   |
      And the remote cache does not contain the packed bundle "json"
      And the local cache does not contain the bundle "json"
     When I run `bundle-depot fetch`
     Then the exit status should be 0 
